==> aws-java-sdk-datapipeline-1.10.75.2-sources.jar: com/amazonaws/services/datapipeline/model/transform/PipelineIdNameJsonMarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.datapipeline.model.transform;

import java.util.Map;
import java.util.List;

import com.amazonaws.AmazonClientException;
import com.amazonaws.services.datapipeline.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.util.json.*;

/**
 * PipelineIdNameMarshaller
 */
public class PipelineIdNameJsonMarshaller {

    /**
     * Marshall the given parameter object, and output to a SdkJsonGenerator
     */
    public void marshall(PipelineIdName pipelineIdName,
            StructuredJsonGenerator jsonGenerator) {

        if (pipelineIdName == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(...)");
        }

        try {
            jsonGenerator.writeStartObject();

            if (pipelineIdName.getId() != null) {
                jsonGenerator.writeFieldName("id").writeValue(
                        pipelineIdName.getId());
            }
            if (pipelineIdName.getName() != null) {
                jsonGenerator.writeFieldName("name").writeValue(
                        pipelineIdName.getName());
            }

            jsonGenerator.writeEndObject();
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }
    }

    private static PipelineIdNameJsonMarshaller instance;

    public static PipelineIdNameJsonMarshaller getInstance() {
        if (instance == null)
            instance = new PipelineIdNameJsonMarshaller();
        return instance;
    }

}

==> aws-java-sdk-datapipeline-1.11.26-sources.jar: com/amazonaws/services/datapipeline/model/transform/PipelineIdNameJsonMarshaller.java <==
/*
 * Copyright 2011-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not
 * use this file except in compliance with the License. A copy of the License is
 * located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.datapipeline.model.transform;

import java.util.Map;
import java.util.List;

import com.amazonaws.AmazonClientException;
import com.amazonaws.services.datapipeline.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.protocol.json.*;

/**
 * PipelineIdNameMarshaller
 */
public class PipelineIdNameJsonMarshaller {

    /**
     * Marshall the given parameter object, and output to a SdkJsonGenerator
     */
    public void marshall(PipelineIdName pipelineIdName,
            StructuredJsonGenerator jsonGenerator) {

        if (pipelineIdName == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(...)");
        }

        try {
            jsonGenerator.writeStartObject();

            if (pipelineIdName.getId() != null) {
                jsonGenerator.writeFieldName("id").writeValue(
                        pipelineIdName.getId());
            }
            if (pipelineIdName.getName() != null) {
                jsonGenerator.writeFieldName("name").writeValue(
                        pipelineIdName.getName());
            }

            jsonGenerator.writeEndObject();
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }
    }

    private static PipelineIdNameJsonMarshaller instance;

    public static PipelineIdNameJsonMarshaller getInstance() {
        if (instance == null)
            instance = new PipelineIdNameJsonMarshaller();
        return instance;
    }

}
